--This file is sql code designed to check if a student meets the eligibilty for the BS-MS CLSE program at VCU
--created by rlwasilewski last update 2023-01-05

--prompts user for current term
DEFINE currentterm

--pulls all info from registration_bio for the entered term for Undergrad CLSE students not deceased
WITH
bio AS (
SELECT DISTINCT
    registration_bio.*
FROM
    registration_bio
WHERE
    academic_period = '&currentterm'
AND student_level1 = 'UG'
AND college1 = 'EG'
AND major1 = 'CLE'
AND deceased_status <> 'Y'),

--connects the bio info to the course registration info
reg AS(
SELECT DISTINCT
    r.*,
    --looks to see if a student received an A,B,C, or is currently enrolled in the pre-req courses for the BS-MS program
    CASE
    WHEN r.course_identification = 'CLSE301' AND (r.final_grade = 'A' OR r.final_grade = 'B' OR r.final_grade = 'C' OR r.final_grade IS NULL) THEN 1
    WHEN r.course_identification = 'CLSE302' AND (r.final_grade = 'A' OR r.final_grade = 'B' OR r.final_grade = 'C'OR r.final_grade IS NULL) THEN 1
    WHEN r.course_identification = 'CLSE305' AND (r.final_grade = 'A' OR r.final_grade = 'B' OR r.final_grade = 'C' OR r.final_grade IS NULL) THEN 1
    WHEN r.course_identification = 'CLSE312' AND (r.final_grade = 'A' OR r.final_grade = 'B' OR r.final_grade = 'C' OR r.final_grade IS NULL) THEN 1
    WHEN r.course_identification = 'CLSE320' AND (r.final_grade = 'A' OR r.final_grade = 'B' OR r.final_grade = 'C' OR r.final_grade IS NULL) THEN 1
END AS course_req,
--looks to see if the student has registered for either Senior Design class
    CASE
    WHEN r.course_identification = 'CLSE402' THEN '1'
    WHEN r.course_identification = 'CLSE403' THEN '1'
END AS s_design
FROM
    registration_enrollment r
WHERE
    census_period = '0'
),

--reduces the registration and bio tables to just what is needed to check eligibility
final AS(
SELECT DISTINCT
bio.first_name,
bio.last_name,
bio.eid_email,
bio.id,
bio.student_classification1,
bio.ug_gpa,
bio.primary_gpa,
re.academic_period AS course_term,
re.course_identification,
re.course_reference_number,
re.course_section_number,
re.final_grade,
re.course_req,
re.s_design,
--adds the number of pre-req courses. Should be 5 for eligibility
SUM(course_req) OVER (PARTITION BY bio.ID) AS req_total,
--adds the number of senior design courses. Should be null for eligibilty
SUM(s_design) OVER (PARTITION BY bio.ID) AS sd_total,
CASE
    WHEN UG_GPA >= 2.95 AND PRIMARY_GPA >= 3.15 THEN 'Y'
END AS gpa_req
FROM reg re
INNER JOIN bio
ON re.id = bio.id
WHERE re.census_period = '0' AND bio.census_period =0
),

--final step to check for num courses and senior design check
prelist AS(
SELECT DISTINCT
final.*,
CASE
--Rachel, delete this, you only had one student elligible on your last check so temp set it okay if student is registered for senior design
    WHEN req_total >= 5 THEN 'Y'
   --WHEN req_total >= 5 AND sd_total IS NULL THEN 'Y'
END AS course_eligible
FROM final
)

SELECT DISTINCT
prelist.first_name,
prelist.last_name,
prelist.id,
prelist.eid_email,
prelist.student_classification1
FROM prelist
WHERE prelist.course_eligible = 'Y' AND prelist.gpa_req = 'Y'
ORDER BY prelist.student_classification1, prelist.last_name

                                    

    